"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeCypressPlugin = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const util_1 = require("util");
const read = util_1.promisify(fs_1.readFile);
const pluginName = 'cypress-transform-html';
const OSSepRE = new RegExp(`\\${path_1.sep}`, 'g');
function convertPathToPosix(path) {
    return path_1.sep === '/'
        ? path
        : path.replace(OSSepRE, '/');
}
const INIT_FILEPATH = path_1.resolve(__dirname, '../client/initCypressTests.js');
const makeCypressPlugin = (projectRoot, supportFilePath, devServerEvents) => {
    let base = '/';
    const posixSupportFilePath = supportFilePath ? convertPathToPosix(path_1.resolve(projectRoot, supportFilePath)) : undefined;
    const normalizedSupportFilePath = posixSupportFilePath ? `${base}@fs/${posixSupportFilePath}` : undefined;
    return {
        name: pluginName,
        enforce: 'pre',
        config(_, env) {
            if (env) {
                return {
                    define: {
                        'import.meta.env.__cypress_supportPath': JSON.stringify(normalizedSupportFilePath),
                        'import.meta.env.__cypress_originAutUrl': JSON.stringify(`__cypress/iframes/${convertPathToPosix(projectRoot)}/`),
                    },
                };
            }
        },
        configResolved(config) {
            base = config.base;
        },
        transformIndexHtml() {
            return [
                // load the script at the end of the body
                // script has to be loaded when the vite client is connected
                {
                    tag: 'script',
                    injectTo: 'body',
                    attrs: { type: 'module' },
                    children: `import(${JSON.stringify(`${base}@fs/${INIT_FILEPATH}`)})`,
                },
            ];
        },
        configureServer: async (server) => {
            const indexHtml = await read(path_1.resolve(__dirname, '..', 'index.html'), { encoding: 'utf8' });
            const transformedIndexHtml = await server.transformIndexHtml(base, indexHtml);
            server.middlewares.use(`${base}index.html`, (req, res) => res.end(transformedIndexHtml));
        },
        handleHotUpdate: () => {
            // restart tests when code is updated
            devServerEvents.emit('dev-server:compile:success');
            return [];
        },
    };
};
exports.makeCypressPlugin = makeCypressPlugin;
